AdaptSizeInit class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- isInitialized → bool
-
no setter
- scaleHeightFactor → double
-
no setter
- scaleWidthFactor → double
-
no setter
- screenHeight → double
-
no setter
- screenWidth → double
-
no setter
- textScaleFactor → double
-
no setter
Static Methods
-
init(
BuildContext context, {required Size designSize}) → void -
reset(
) → void -
scaleHeight(
double value) → double -
scaleHeightByRatio(
double value, double ratio) → double -
scaleText(
double fontSize, {bool respectSystemScale = true}) → double -
scaleWidth(
double value) → double -
scaleWidthByRatio(
double value, double ratio) → double